/**
 * @file ip.cc
 * @brief A IP class, that handles all about time.
 *
 * code taken from audiere.
 */

#include "ip.h"
#include "multi_type.h"
#include "substring.h"

IP::IP()
{
  this->_ip = 0;
  this->_port = 0;
}


IP::IP(int ip, int port)
{
  this->_ip = ip;
  this->_port = port;
}



IP::IP(const std::string& ip)
{
  *this = IP::stringToIP(ip);
}


IP::IP(const IPaddress& ip)
{
  this->_ip = ip.host;
  this->_port = ip.port;
}


IP::IP(const IP& ip)
{
  this->_ip = ip.ip();
  this->_port = ip.port();
}



const IP& IP::operator=(const IP& ip)
{
  this->_ip = ip.ip();
  this->_port = ip.port();
  return *this;
}



bool IP::operator==(const IP& ip)
{
  return (this->_ip == ip.ip() && this->_port == ip.port());
}


/**
 * @returns The retrieved IP
 *
 */
IP IP::stringToIP(const std::string& ip)
{
  IPaddress ipaddr;

  SDLNet_ResolveHost(&ipaddr, NULL, 2000);

  return IP(ipaddr);

  /*
  SubString addr(ip, '.');
  if(ip.size() != 4 )
    return -1;

  MultiType part0(ip[0]);
  MultiType part1(ip[1]);
  MultiType part2(ip[2]);
  MultiType part3(ip[3]);
  */
}

int IP::ipPart(unsigned int part) const
{
  switch (part)
  {
    case 0:
      return  (_ip & 0xFF000000) >> 24;
    case 1:
      return  (_ip & 0x00FF0000) >> 16;
    case 2:
      return  (_ip & 0x0000FF00) >> 8;
    case 3:
      return  (_ip & 0x000000FF);
    default:
      return -1;
  }

}


std::string IP::ipString() const
{
  return IP::ipToString(this->_ip);
}


std::string IP::ipToString(const IPaddress& ipaddr)
{
  int ip = SDLNet_Read32 (ipaddr.host);
  return ipToString(ip);
}





std::string IP::ipToString(int ip)
{
  MultiType part0((int) (ip & 0xFF000000) >> 24);
  MultiType part1((int) (ip & 0x00FF0000) >> 16);
  MultiType part2((int) (ip & 0x0000FF00) >>  8);
  MultiType part3((int) (ip & 0x000000FF) );


  return part0.getString() + "." + part1.getString() + "." +
         part2.getString() + "." + part3.getString();
}

